<template>
  <a-card
    :bordered="false"
    :class="'cust-erp-sub-tab'"
  >
    <a-table
      ref="table"
      bordered
      rowKey="id"
      :columns="columns"
      :dataSource="dataSource"
      :pagination="ipagination"
      @change="handleTableChange"
    >

      <template
        v-for="col in columns"
        :slot="col.dataIndex"
        slot-scope='text, record, index'
      >
        <div :key="col.dataIndex">
          <a-input
            :value="text"
            v-if="col.dataIndex == 'sparePartId'"
            auto-size
            placeholder="请输入物料名称"
            @change="(e)=>handleChange(e, record.key, col, index)"
            :disabled="record.disabled"
          />
          <a-input
            :value="text"
            v-if="col.dataIndex == 'repairOrderAmUda1'"
            auto-size
            placeholder="请输入单位"
            @change="(e)=>handleChange(e, record.key, col, index)"
            :disabled="record.disabled"
          />
          <j-dict-select-tag
            :value='text'
            v-if="col.dataIndex == 'outboundOrderId'"
            dictCode="material_type"
            :disabled="false"
            style="width: 100%;"
            @change='(e)=>handleChange(e, record.key, col, index)'
          />
          <a-input-number
            :value="text"
            v-if="col.dataIndex == 'actualQuantity'"
            :min="1"
            :max="99999"
            @change="(e)=>handleChange(e, record.key, col, index)"
            :disabled="record.isLock == 'yes'||mainId.status=='4'"
          />

        </div>
      </template>
      <span
        slot='action'
        slot-scope='text, record,index'
      >
        <a
          :disabled="mainId.status=='4'"
          @click='handleDelete(index)'
        >删除</a>
      </span>
      <!-- <span
        slot='action'
        slot-scope='text, record'
      >
        <a-popconfirm
          title="确认锁料吗?"
          @confirm="() => handleLock(record)"
        >
          <a v-if="record.isLock=='no'&&mainId.status=='3'">锁料</a>
        </a-popconfirm>
        <a-divider
          v-if="record.isLock=='no'"
          type="vertical"
        />
        <a-popconfirm
          title="解锁后会自动释放库存，确认解锁吗?"
          @confirm="() => handleUnLock(record)"
        >
          <a v-if="record.isLock=='yes'&&mainId.status=='3'">解锁</a>
        </a-popconfirm>
        <a-popconfirm
          title="确定删除吗?"
          @confirm="() => handleDelete(record.id)"
        >
          <a v-if="record.isLock=='no'&&mainId.status=='3'">删除</a>
        </a-popconfirm>
      </span> -->
    </a-table>
    <a-button
      style="width: 100%; margin-top: 16px; margin-bottom: 8px"
      type="dashed"
      icon="plus"
      @click="addMaterial"
      :disabled="mainId.status!='3'"
    >添加实际用料</a-button>
    <!-- :disabled="mainId.status!='3'||( mainId.repairOrderUda1!='needPart'&&mainId.repairOrderUda1!='needSpare')" -->
    <div :style="{width: '100%',border: '1px solid #e9e9e9',padding: '10px 16px',background: '#fff',}">
      <a-row :style="{textAlign:'right'}">
        <a-button
          :style="{marginRight: '8px'}"
          @click='handleCancel'
        >
          取消
        </a-button>
        <!-- <a-button
          @click='handleOk(1)'
          type='primary'
          :style="{marginRight: '8px'}"
          :disabled="this.repairOrderStatus=='4' || this.repairOrderStatus=='2'"
        >暂存
        </a-button> -->
        <a-button
          @click='handleOk(0)'
          type='primary'
          :disabled="this.mainId.status=='4' || this.mainId.status=='2'"
        >保存
        </a-button>
      </a-row>
      <!-- :disabled="false" -->
    </div>
    <j-select-spare-part-modal ref='JSelectSparePartModal'></j-select-spare-part-modal>
  </a-card>
</template>
<script>
import { postAction, getAction } from '@/api/manage'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import pick from 'lodash.pick'
import JEllipsis from '@/components/jeecg/JEllipsis'
import JSelectSparePartModal from './select/JSelectSparePartModal'
// import RepairOrderActualMaterialReportModel from './RepairOrderActualMaterialReportModel.vue'
export default {
  name: 'RepairOrderActualMaterialReport',
  mixins: [JeecgListMixin],
  components: {
    JEllipsis,
    JSelectSparePartModal,
  },
  props: {
    mainId: {
      type: Object,
    }
  },
  data() {
    return {
      title: "实际用料",
      visible: false,
      model: {},
      maskClosable: true,
      confirmLoading: false,
      // specialyMaintenanceOrderStatus: '',
      form: this.$form.createForm(this),
      /* 分页参数 */
      ipagination: {
        current: 1,
        pageSize: 99,
        pageSizeOptions: ['99', '199'],
        showTotal: (total, range) => {
          return range[0] + "-" + range[1] + " 共" + total + "条"
        },
        showQuickJumper: true,
        showSizeChanger: true,
        total: 0
      },
      validatorRules: {
        materialId: {
          rules: [
            { required: true, message: '请选择物料!' },
          ]
        },
        actualQuantity: {
          rules: [
            { required: false, message: '请填写数量!' },
          ]
        },
      },
      labelCol: {
        xs: { span: 24 },
        sm: { span: 7 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 },
      },
      drawerWidth: "100%",
      visible: false,
      disableSubmit: false,
      disableSelect: false,
      loading: false,
      dataSource: [],
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: "center",
          customRender: function (t, r, index) {
            return parseInt(index) + 1;
          }
        },
        {
          title: '物料名称',
          dataIndex: 'sparePartId',
          scopedSlots: { customRender: 'sparePartId' },
          align: "center",
          className: 'red',
          // width: 250,
        },
        {
          title: '物料种类',
          dataIndex: 'outboundOrderId',
          scopedSlots: { customRender: 'outboundOrderId' },
          align: "center",
          // width: 250,
        },
        {
          title: '使用数量',
          dataIndex: 'actualQuantity',
          align: "center",
          scopedSlots: { customRender: 'actualQuantity' },
          className: 'red',
        },
        {
          title: '单位',
          dataIndex: 'repairOrderAmUda1',
          scopedSlots: { customRender: 'repairOrderAmUda1' },
          align: "center",
          className: 'red',
        },

        {
          title: '操作',
          dataIndex: 'action',
          align: 'center',
          scopedSlots: { customRender: 'action' }
        }
      ],
      url: {
        list: '/eam/repairOrderActualMaterial/list',
        confirmMaterial: "/eam/repairOrderActualMaterial/addNew",
        delete: "/eam/repairOrderActualMaterial/delete",
        addInit: "/eam/repairOrderActualMaterial/addInit",
        lock: "/eam/repairOrderActualMaterial/lock",
        unLock: "/eam/repairOrderActualMaterial/unLock"
      },
      changeIndex: 0
    }
  },
  watch: {
    mainId: {
      immediate: true,
      deep: true,
      handler(val) {
        console.log(val)
        if (!this.mainId.id) {

          this.clearList()
        } else {
          this.queryParam['repairOrderId'] = val.id
          this.loadData(1)
        }
      }
    }
  },
  // created() {
  // this.queryParam['maintenanceOrderId'] = this.dailyMaintenanceOrderId;
  // this.queryParam['equipmentId'] = this.equipmentId
  // this.loadData(1);
  // console.log("77777777", this.mainId)
  // },
  methods: {
    addMaterial() {
      // let ids = [];
      // for (let i = 0; i < this.dataSource.length; i++) {
      //   ids.push(this.dataSource[i].outboundOrderDetailId);
      // }
      // this.$refs.JSelectSparePartModal.showModals(ids);
      // this.$refs.JSelectSparePartModal.title = '选择备件信息'
      // this.$refs.JSelectSparePartModal.disableSubmit = false
      // this.dataSource.push({ sparePartId: '', outboundOrderId: this.mainId.repairOrderUda1, repairOrderAmUda1: '', actualQuantity: '', repairOrderId: this.mainId.id })
      this.dataSource.push({ sparePartId: '', outboundOrderId: '', repairOrderAmUda1: '', actualQuantity: '', repairOrderId: this.mainId.id })
    },
    handleCancel() {
      this.$bus.$emit('closeDrawer')
    },
    close() {
      this.$emit('close');
      this.dataSource = [];
      this.disableSubmit = false;
      this.visible = false;
    },
    handleDeleteFake(index) {
      this.dataSource.pop(index);
    },
    handleChange(value, key, column, index) {
      console.log(column)
      const temp = [...this.dataSource]
      const target = temp[index]
      // let availableQuantity = target['availableQuantity']
      // if (target) {
      //   if (value != undefined && value != null && value != '' && availableQuantity < value) {
      //     this.$message.error('使用数量不能大于可用数量!')
      //   } else {
      //   }
      //   target[column.dataIndex] = value
      //   this.dataSource = temp
      // }
      if ('sparePartId' == column.dataIndex) {
        target['sparePartId'] = value.target.value
      }
      if ('repairOrderAmUda1' == column.dataIndex) {
        target['repairOrderAmUda1'] = value.target.value
      }
      if ('actualQuantity' == column.dataIndex) {
        target['actualQuantity'] = value
      }
      if ('outboundOrderId' == column.dataIndex) {
        target['outboundOrderId'] = value
      }
    },
    clearList() {
      this.dataSource = [];
      this.ipagination.current = 1
    },
    // getUuiD(randomLength) {
    //   return Number(
    //     Math.random()
    //       .toString()
    //       .substr(2, randomLength) + Date.now()
    //   ).toString(36)
    // },
    handleLock(record) {
      let that = this;
      if (record.actualQuantity == null || record.actualQuantity == undefined || record.actualQuantity == '') {
        this.$message.error('请先填写数量!');
        return false
      }
      if (record.availableQuantity < record.actualQuantity) {
        this.$message.error('使用数量不能大于可用数量!');
        return false;
      }
      this.confirmLoading = true;
      postAction(this.url.lock, record).then(res => {
        if (res.success) {
          this.$message.success("库存锁定成功！")
        } else {
          this.$message.error(res.message)
        }
      }).finally(res => {
        that.confirmLoading = false
        that.loadData();
      })

    },
    handleUnLock(record) {
      let that = this;
      this.confirmLoading = true;
      postAction(this.url.unLock, record).then(res => {
        if (res.success) {
          this.$message.success("库存解锁成功！")
        } else {
          this.$message.error(res.message)
        }
      }).finally(res => {
        that.confirmLoading = false
        that.loadData();
      })
    },
    loadData(arg) {
      if (!this.url.list) {
        this.$message.error('请设置url.list属性!')
        return
      }
      //加载数据 若传入参数1则加载第一页的内容
      if (arg === 1) {
        this.ipagination.current = 1
      }
      // this.queryParam['maintenanceOrderId'] = this.dailyMaintenanceOrderId
      // this.queryParam['equipmentId'] = this.equipmentId
      var params = this.getQueryParams() //查询条件
      this.loading = true
      getAction(this.url.list, params)
        .then(res => {
          if (res.success) {
            //update-begin---author:zhangyafei    Date:20201118  for：适配不分页的数据列表------------
            this.dataSource = res.result.records || res.result
            if (res.result.total) {
              this.ipagination.total = res.result.total
            } else {
              this.ipagination.total = 0
            }
            //update-end---author:zhangyafei    Date:20201118  for：适配不分页的数据列表------------
          } else {
            this.$message.warning(res.message)
          }
        })
        .finally(() => {
          this.loading = false
        })
    },
    handleOk(saveStatus) {
      const that = this
      if (saveStatus == 0) {
        let workHoursDataSource = that.dataSource
        for (let i = 0; i < workHoursDataSource.length; i++) {
          if (workHoursDataSource[i].sparePartId == undefined || workHoursDataSource[i].sparePartId == null || workHoursDataSource[i].sparePartId == '') {
            that.$message.warning('请选择第' + (i + 1) + '行物料名称！')
            return false
          }
          if (workHoursDataSource[i].repairOrderAmUda1 == undefined || workHoursDataSource[i].repairOrderAmUda1 == null || workHoursDataSource[i].repairOrderAmUda1 == '') {
            that.$message.warning('请填写第' + (i + 1) + '行单位！')
            return false
          }
          if (workHoursDataSource[i].actualQuantity == undefined || workHoursDataSource[i].actualQuantity == null || workHoursDataSource[i].actualQuantity == '') {
            that.$message.warning('请填写第' + (i + 1) + '行使用数量！')
            return false
          }
          if (workHoursDataSource[i].outboundOrderId == undefined || workHoursDataSource[i].outboundOrderId == null || workHoursDataSource[i].outboundOrderId == '') {
            that.$message.warning('请填写第' + (i + 1) + '行物料种类！')
            return false
          }
        }
      }
      if (that.dataSource.length === 0) {
        that.$message.warning('请添加用料！')
        return
      }
      this.form.validateFields((err, values) => {
        if (!err) {
          that.confirmLoading = true
          let formData = that.dataSource;
          let obj = obj = postAction(this.url.confirmMaterial, formData)
          obj.then((res) => {
            if (res.success) {
              that.$message.success(res.message)
              that.$emit('ok')
            } else {
              that.$message.warning(res.message)
            }
          }).finally(() => {
            that.confirmLoading = false
            that.close()
            that.loadData(1)
          })
        }
      })
    },
    handleDelete(index) {
      console.log(index)
      this.dataSource.splice(index, 1)
    },
  },
  // mounted() {
  //   let newActualMaterials = [];
  //   this.$bus.$on('selection3Rows', (data) => {
  //     for (let i = 0; i < data.length; i++) {
  //       newActualMaterials.push({
  //         // id: this.getUuiD(16),
  //         num: data[i].num,
  //         outboundOrderDetailId: data[i].id,
  //         sparePartId: data[i].sparePartId,
  //         // sparePartNum: data[i].spareNum,
  //         // sparePartName: data[i].spareName,
  //         // sparePartSpecification: data[i].specification,
  //         // sparePartModel: data[i].model,
  //         // constructorName: data[i].constructorName,
  //         // constructorId: data[i].constructorId,
  //         // mainUnitName: data[i].mainUnitName,
  //         // mainUnitId: data[i].mainUnitId,
  //         mainQuantity: data[i].mainQuantity,
  //         useQuantity: data[i].useQuantity,
  //         availableQuantity: data[i].availableQuantity,
  //         repairOrderId: this.mainId.id,
  //         equipmentId: this.equipmentId,
  //         isLock: 'no'
  //       })
  //     }
  //     let that = this
  //     postAction(this.url.addInit, newActualMaterials).then((res) => {
  //       if (res.success) {
  //         that.$message.success(res.message)
  //         newActualMaterials = []
  //         that.$emit('ok')
  //       } else {
  //         that.$message.warning(res.message)
  //       }
  //     }).finally(res => {
  //       that.loadData();

  //     })
  //   })
  // },

}
</script>

<style scoped>
/deep/ .red {
  color: red;
}
</style>